#!/bin/bash
. /etc/init.d/functions

ccm_check_wave_database_integrity () {

    if [ -f ${FWDL_DB_COPY_LOG} ]; then
        log_to_pg_file "file check passed."
    else
        touch ${FWDL_DB_COPY_LOG} 2>/dev/null
    fi

    log_to_pg_file "CCM Starting to check WaveDatabase Integrity...."

    if [ ${iscfgcleanup} -eq 1 -o ${isautorecovery} -eq 1 ]; then
        log_to_pg_file "CCM WaveDatabase Integrity Not required as cfgcleanup/autorecovery is done in this boot...."
        log_to_pg_file ccm_check_wave_database_integrity...end
        return 0;
    fi

    # Clean up existing cfg and log files. 

    rm -f /etc/fabos/Ccmd/WaveDatabase/postmaster.pid 2>/dev/null

    local ccm_rc=1
    ccmd_wavecurrent_exists=0
    ccmd_wavestart_exists=0


    log_to_pg_file "Ccmd needs to be launched."  
    if [ ! -d /etc/fabos/Ccmd/WaveDatabase ]; then
        return 1;
    fi

    start_postgres_server "/etc/fabos/Ccmd/WaveDatabase" 9017 "CCM" 

    if [ $? -ne 0 ]; then
        log_to_pg_file "failed to connect to Ccmd database."

        echo "Ccmd Database is corrupted. Hence, clearing the database."
        log_to_pg_file "Ccmd Database is corrupted. Hence, clearing the database."
        rm -rf /etc/fabos/Ccmd/WaveDatabase
        rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
 
        return 1;
    fi

    /usr/local/postgresql/${POSTGRES_VERSION}/bin/psql WaveDatabase -p 9017 -c "\dn" > /tmp/ccmd_schema_info 2>&1
    ccmd_schema_output=`cat /tmp/ccmd_schema_info`
    ccmd_wavecurrent_exists=`echo ${ccmd_schema_output} | grep -c -i -e "wavecurrent"`
    ccmd_wavestart_exists=`echo ${ccmd_schema_output} | grep -c -i -e "wavestart"`
    rm -f /tmp/ccmd_schema_info

    if [ ${ccmd_wavecurrent_exists} -eq 1 -a ${ccmd_wavestart_exists} -eq 1 ]; then
        local MAX_RETRIES=60
        local SLEEP_TIME=8
        let TIMEOUT_MINUTES=${MAX_RETRIES}*${SLEEP_TIME}/60

        log_to_pg_file "postmaster running for Ccmd..Starting database dump, restore for Ccmd." 
        
        monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_dump" 9017 "-f /tmp/ccmd_db_dump -Ft WaveDatabase" ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
        ccm_rc=$?

        log_to_pg_file "dump for ccmd database ended. ccm_rc=$ccm_rc."
        
        if [ ${ccm_rc} -eq 0 ]; then
            log_to_pg_file "ccmd dump succeeded."

            clean_prepared_trasaction WaveDatabase 9017
            log_to_pg_file "ccmd clean_prepared_trasaction done."

            monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/psql" 9017 '-c "drop schema wavecurrent cascade;drop schema wavestart cascade;" WaveDatabase' ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
            ccm_rc=$?

            log_to_pg_file "dropped schemas before restore. ccm_rc=$ccm_rc."

            if [ ${ccm_rc} -eq 0 ]; then
                monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore" 9017 "-d WaveDatabase /tmp/ccmd_db_dump" ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
                ccm_rc=$?

                log_to_pg_file "restore done from the ccmd dump file taken during db corruption detection. ccm_rc=$ccm_rc."

                if [ ${ccm_rc} -eq 0 ]; then
                    monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/psql" 9017 '-c "vacuum;" WaveDatabase' ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
                    ccm_rc=$?

                    log_to_pg_file "vacuum done on restored ccmd db to detect corrupted indexes. ccm_rc=$ccm_rc."

                    if [ ${ccm_rc} -eq 0 ]; then
                        log_to_pg_file "ccmd vacuum succeeded."
                    else
                        log_to_pg_file "ccmd vacuum failed."

                        if [ ${ccm_rc} -eq 254 ]; then
                            log_to_raslog DCM-3010 Ccmd ${TIMEOUT_MINUTES}
                        fi
                    fi
                else
                    log_to_pg_file "ccmd restore failed."

                    if [ ${ccm_rc} -eq 254 ]; then
                        log_to_raslog DCM-3010 Ccmd ${TIMEOUT_MINUTES}
                    fi
                fi
            else
                log_to_pg_file "ccmd empty database for restore preparation failed. Hence not attempting restore."

                if [ ${ccm_rc} -eq 254 ]; then
                    log_to_raslog DCM-3010 Ccmd ${TIMEOUT_MINUTES}
                fi
            fi
        else
            log_to_pg_file "ccmd dump failed. Hence not attempting restore."

            if [ ${ccm_rc} -eq 254 ]; then
                log_to_raslog DCM-3010 Ccmd ${TIMEOUT_MINUTES}
            fi
        fi

        rm -f /tmp/ccmd_db_dump
    else
        log_to_pg_file "WaveCurrent/WaveStart of Ccmd DB doesn't exist."  
        ccm_rc=0
    fi

    log_to_pg_file "stopping Ccmd postgres servers." 
    stop_postgres_server "/etc/fabos/Ccmd/WaveDatabase"

    # Cleanup Ccmd database and cfg file when database is in bad state
    if [ ${ccm_rc} -ne 0 ]; then
        echo "Ccmd Database is corrupted. Hence, clearing the database."
        log_to_pg_file "Ccmd Database is corrupted. Hence, clearing the database." 
        log_to_raslog DCM-3053 Ccmd

        rm -rf /etc/fabos/Ccmd/WaveDatabase
        rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
    else
        log_to_pg_file "Ccmd database is good." 
    fi
    # Cleanup Ccmd database and cfg file when the required schemar is missing
    if [ ${ccmd_wavecurrent_exists} -ne 1 -o ${ccmd_wavestart_exists} -ne 1 ] ; then
        echo "In Ccmd WaveDatabase, wavecurrent(${ccmd_wavecurrent_exists})/wavestart(${ccmd_wavestart_exists}) schema doesn't exist."
        echo "Treating this as Database corruption. Hence clearing the database."
        rm -rf /etc/fabos/Ccmd/WaveDatabase
        rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
    else
        log_to_pg_file "Ccmd WaveDatabase contains both wavecurrent and wavestart schemas." 
    fi

    log_to_pg_file "ccm_check_wave_database_integrity...end."
}

ccm_copy_wavedb_from_secondary() {

    log_to_pg_file "CCM Starting to copy waveDb and confd cdb from Secondary...."

    # Clean up existing cfg and log files. 

    rm -f /mnt/etc/fabos/Ccmd/WaveDatabase/postmaster.pid ${FWDL_DB_COPY_LOG} ${FWDL_CCMDB_DUMP_FILE} /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg


    # removing the cfg file as it is possible the mnt partition may not have cfg file. If that is the case, copy will fail and current partition will old incorrect data in cfg file.
    rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
    cp -f /mnt/etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg

    status=1

    # copy CCMD database
    if [ -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg ]
    then
        log_stage_start "CCMd DB copy from secondary to primary"

        log_stage_start "CCMd DB server launch"
        start_postgres_server "/mnt/etc/fabos/Ccmd/WaveDatabase" 9016 "/etc/fabos/Ccmd/WaveDatabase" 9017 "CCM" 1

        if [ $? -ne 0 ]; then
            log_to_pg_file "failed to connect to Ccmd database." 
            # if db copy failed, we should remove cfg file
            rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
            return
        fi
        log_stage_end "CCMd DB server launch"

        log_to_pg_file postmaster running..Starting Ccmd database copy 
        log_stage_start "CCMd DB dump"
        #echo " Copying Ccmd database"
        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_dump -p 9016 -f ${FWDL_CCMDB_DUMP_FILE} -Ft WaveDatabase 2>>${FWDL_DB_COPY_LOG}
        log_stage_end "CCMd DB dump"

        log_stage_start "CCMd DB restore"
        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore -d WaveDatabase -p 9017 ${FWDL_CCMDB_DUMP_FILE} >>${FWDL_DB_COPY_LOG} 2>&1
        rc2=$?
        log_to_pg_file copy done. rc $rc2 
        if [ $rc2 -ne 0 ]
        then
            log_to_pg_file Ccmd DB restore failed whil restoring from mnt partition . retStatus = $rc2
            log_to_pg_file Hence to recover from this DB corruption, going to First time boot.
            rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
        fi
        log_stage_end "CCMd DB restore"
        #echo " done"

        stop_postgres_server "/mnt/etc/fabos/Ccmd/WaveDatabase" "/etc/fabos/Ccmd/WaveDatabase"
        log_stage_end "CCMd DB copy from secondary to primary"
    fi

    log_to_pg_file ccm_copy_wavedb_from_secondary...end
}

ccm_handle_db_restore_if_required() {

    #Ccmd handling
    if [ -f $FWDL_CCMDB_DUMP_FILE ]; 
    then

        # Restore CCM DB as db converison was not complete.
        log_to_pg_file "############## Restoring the CCM database as dn conversion was not complete.######################" 

        rm -f /etc/fabos/Ccmd/WaveDatabase/postmaster.pid 
        
        start_postgres_server "/etc/fabos/Ccmd/WaveDatabase" 9017 "CCM"

        if [ $? -ne 0 ]; then
            log_to_pg_file "failed to connect to Ccmd database" 
            return
        fi

        log_to_pg_file "postmaster running..Starting database copy" 
        
        clean_prepared_trasaction WaveDatabase 9017
        log_to_pg_file ccmd clean_prepared_trasaction done

        /usr/local/postgresql/${POSTGRES_VERSION}/bin/psql WaveDatabase -p 9017 -c "drop schema wavecurrent cascade;drop schema wavestart cascade;" >>${FWDL_DB_COPY_LOG} 2>&1
        rc1=$?
        log_to_pg_file dropped schemas before restore rc=$rc1 

        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore -d WaveDatabase -p 9017 ${FWDL_CCMDB_DUMP_FILE} >>${FWDL_DB_COPY_LOG} 2>&1
        rc1=$?
        log_to_pg_file copy done. rc $rc1 
        if [ $rc1 -ne 0 ]
        then
            log_to_pg_file Dcmd DB restore failed whil restoring $FWDL_CCMDB_DUMP_FILE. retStatus = $rc1 
            log_to_pg_file Hence to recover from this DB corruption, going to First time boot.
            rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
        fi
        #echo " done"

        stop_postgres_server "/etc/fabos/Ccmd/WaveDatabase"

        isschemachangetobedetected="true"
    fi

}


ccm_handle_fwdl() {
    swbd_num=${SWBD##SWBD}
    log_to_pg_file ccm_handle_fwdl : swbd_num:${swbd_num}
    rb_reason=`cat /mnt/var/rb_reason`
    log_to_pg_file "ccm_handle_fwdl : ******Reboot reason : ${rb_reason}******"

    PG_VERSION=`ls /usr/local/postgresql | cut -d '/' -f1`

    PGMNT_VERSION=`ls /mnt/usr/local/postgresql | cut -d '/' -f1`

    # In fwdl case, vcs.conf needs to be copied from secondary partition before we determine the number of daemons

    cp -f /mnt/etc/fabos/Dcmd/vcs.conf /etc/fabos/Dcmd/vcs.conf

    rm -rf /etc/fabos/Ccmd/PrismDatabase.previous.pgd
    rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.trc*
    cp -f /mnt/etc/fabos/Ccmd/Ccmd.Linux.powerpc.trc* /etc/fabos/Ccmd/
    rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.pg_ctl.log*
    cp -f /mnt/etc/fabos/Ccmd/Ccmd.Linux.powerpc.pg_ctl.log* /etc/fabos/Ccmd/

    isschemachangetobedetected="true"
        
    isissufwdl=0   
    is_issu_fwdl_reboot ${rb_reason}
    if [ $? -eq 1 ]; then
        isissufwdl=1
    fi
    #copy postgres related files only when there is no postgres's version change

    if [ $PG_VERSION == $PGMNT_VERSION ]
    then

        if [ -f /mnt/etc/fabos/Ccmd/PrismDatabase.previous.pgd ]
        then
            cp /mnt/etc/fabos/Ccmd/PrismDatabase.previous.pgd /etc/fabos/Ccmd/PrismDatabase.previous.pgd
        fi

        if [ -f /mnt/etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd ]; then
            rm -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
            iscfgcleanup=1

            if [[( ! -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg && ! -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg )]]; then
                rm -f /mnt/etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd
            fi
        elif [ ${isissufwdl} -eq 1 ];then
            rm -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
            iscfgcleanup=1
            log_to_pg_file "Cfgcleanup done on standbyGOS for ISSU FWDL"
        else
            ccm_copy_wavedb_from_secondary

            if [ -f /mnt/etc/fabos/Dcmd/SchemaConversionDwnGrd.sh ]; then
                cp /mnt/etc/fabos/Dcmd/SchemaConversionDwnGrd.sh /etc/fabos/Dcmd/SchemaConversionDwnGrd.sh
            
                /etc/fabos/Dcmd/SchemaConversionDwnGrd.sh
            fi
        fi
    fi   

    if [ -L /etc/fabos/Ccmd/yang ]
    then
        rm -f /etc/fabos/Ccmd/yang
    fi

    firmwaredownloadcase=`cat /etc/fabos/Ccmd/vcs.conf.fwdl.ccmd`
    rm -f /etc/fabos/Ccmd/vcs.conf.fwdl.ccmd

    touch /etc/fabos/Ccmd/startupFile.bk

    if [ ${swbd_num} -lt 1004 -o ${swbd_num} -gt 1007 ]; then
        is_abrupt_reboot ${rb_reason}
        if [ $? -eq 1 ]; then
            isabruptreboot="true"
        fi
    fi
}

ccm_handle_reboot() {

    swbd_num=${SWBD##SWBD}
    log_to_pg_file ccm_handle_reboot : swbd_num:${swbd_num}
    rb_reason=`cat /var/rb_reason`
    log_to_pg_file "ccm_handle_reboot : ******Reboot reason : ${rb_reason}******"

    if [ "pAutoRecoveryForDBCorruption" == p"${rb_reason}" ]; then
        if [ -f /etc/fabos/Ccmd/.WaveDatabaseFoundCorrupted ]; then 
                log_to_pg_file "Ccm : Removing Ccmd.*.cfg file as this reboot was because of auto recovery for database corruption."
                rm -rf /etc/fabos/Ccmd/*cfg /etc/fabos/Ccmd/*cfg.bk
                isautorecovery=1
        fi
    fi

    if [ -f /etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd ]; then
        rm -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
        iscfgcleanup=1

        if [[( ! -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg && ! -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg )]]; then
            rm -f /etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd
        fi
    fi

    if [ ${swbd_num} -lt 1004 -o ${swbd_num} -gt 1007 ]; then
        ishafailover=0
        is_ha_failover_reboot ${rb_reason}
        if [ $? -eq 1 ]; then
            ishafailover=1
        fi

        isTorSwitch=0
        is_tor_switch ${swbd_num}
        if [ $? -eq 1 ]; then
            isTorSwitch=1
        fi  
            
        if [ ${isTorSwitch} -eq 1 -a ${ishafailover} -eq 1 ]; then
            log_to_pg_file "Ccm : This is a case of haFailover on TOR platform. Hence, clearing the cfg and db."
            rm -rf /etc/fabos/Ccmd/WaveDatabase
            rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
            iscfgcleanup=1  
        else
            is_abrupt_reboot ${rb_reason}
            if [ $? -eq 1 ]; then
                isabruptreboot="true"
                if [ ${swbd_num} -ne 138 ]; then
                    ccm_check_wave_database_integrity 
                else
                    /fabos/libexec/mmi_early_sr6_update
                    if [ $? -eq 1 ]; then
                        ccm_check_wave_database_integrity
                    else
                        rm -rf /etc/fabos/Ccmd/WaveDatabase
                        rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
                    fi
            fi
        fi
        fi

        ccm_handle_db_restore_if_required
        #echo schemachangetobedetected=${isschemachangetobedetected}
    fi
}




SWBD=`sin | swbd 2> ${NULL}`
CPID=`sin | cpid 2> ${NULL}`

#
# Emulator Support
#
MY_EMUL_FILE=/users/emulator
EMUSWBD=""
if [ -a $MY_EMUL_FILE ]; then
	EMUSWBD=`cat $MY_EMUL_FILE`
	echo $EMUSWBD ${EMUSWBD##SWBD}
	case ${EMUSWBD##SWBD} in
		'1' )
			echo "Emulation $EMUSWBD/153 Platform"
			SWBD="SWBD153"
			;;
		'153' | '154' )
			echo "Emulation $EMUSWBD Platform"
			SWBD=$EMUSWBD
			;;
		*)
			echo "  "
			;;
	esac
fi


echo "Starting Ccmd ... `/bin/date`"

isschemachangetobedetected="false"
needdbcorruptiontobehandled="true"
firmwaredownloadcase=0                                       #0 - no firmware download case, 1 - firmware upgrade case, 2 firmware downgrade case
isabruptreboot="false"
isautorecovery=0
iscfgcleanup=0

# Check if VCS needs to be enabled.
if [ -f /etc/fabos/vcs/vcs.conf ]; then
    SYSDRV_CONFIG=1 #$(($SYSDRV_CONFIG | $SYS_CFG_VCS_ENABLED))
fi


# to keep db conversion disabled after fwdl: touch file /etc/fabos/Dcmd/disableschemaconversion
# AND in Ccmd everytime on boot-up (as Ccmd has detectSchemaChange flag enabled on every boot.)
# both the lines ('touch /etc/fabos/Dcmd/disableschemaconversion' and 'touch /etc/fabos/Ccmd/disableschemaconversion') will be removed from this file when db conversion is to be enabled. 
# touch /etc/fabos/Ccmd/disableschemaconversion

# Persist the VCS mode from previous partition in case of firmware upgrade
# Note :Existence of the file /etc/fabos/Dcmd/vcs.conf.fwdl denotes the firmware download case 
#       And the content of the file gives the fwdl case (i.e. 0:same/nightly firmware download, 1:fwdl upgrade, -1:fw downgrade).

if [ -f /etc/fabos/Ccmd/vcs.conf.fwdl.ccmd ]
then
    ccm_handle_fwdl
else
    ccm_handle_reboot
fi   #End of vcs.conf.fwdl check


$ECHO -n "Starting Ccmd ... "
$ECHO `/bin/date`


# Get the HaId using sin
cpId=`/sbin/sin | grep "Control Processor" | cut -d':' -f2`
haId=`expr ${cpId} + 1`

# lo            = loopback interface
# eth0          = management interface
# eth1          = interface communication b/w Standby GOS and Active GOS
# vlan0.4093    = remote communications
# eth2          = backplane interface

mgmtinterfacereceiverlist="lo:eth0:"
waveclientreceiverlist="lo:eth0:"
interlocationreceiverlist="vlan0.4093:"
httpinterfacereceiverlist="lo:"

case ${SWBD##SWBD} in
'1000' | '1001' | '1002' | '1003')
    # include backplane interface for a chassis system
    backplaneinterface="eth2:"
    mgmtinterfacereceiverlist=${mgmtinterfacereceiverlist}${backplaneinterface}${interlocationreceiverlist}
    waveclientreceiverlist=${waveclientreceiverlist}${backplaneinterface}${interlocationreceiverlist}
    ;;
'131' | '137' | '138' | '151' | '153' | '154' | '155' | '156' | '164')
    # include GOS communication interface for a castor/castor-t, embedded s/w
    standbyGOSConnectToActiveGOS="eth1:"
    mgmtinterfacereceiverlist=${mgmtinterfacereceiverlist}${standbyGOSConnectToActiveGOS}${interlocationreceiverlist}
    waveclientreceiverlist=${waveclientreceiverlist}${standbyGOSConnectToActiveGOS}${interlocationreceiverlist}
esac

case ${SWBD##SWBD} in
'1004' | '1005' | '1006' | '1007')
    ;;
*)
    # Limit Stack size to 1 MB.
    ulimit -Ss 256

    log_to_pg_file ccmd : schemachangetobedetected=${isschemachangetobedetected}
    log_to_pg_file ccmd : isabruptreboot=${isabruptreboot}

    # swbd is mandatory while starting Dcmd,Ccmd and the value should not be zero    
    echo "/fabos/libexec/Ccmd.Linux.powerpc -confdport 4565 -enabledb true -dbport 7013 -mgmtport 7110 -port 5016 -clientport 7710 -eth vlan0.4093 -ipot true -daemon true -usefs false -syslog false -chdir /etc/fabos/Ccmd -vcsconfpath /etc/fabos/Ccmd -distributionmode CCM_ONLY -httpport 2401 -haport 4516 -hapeerport 4516 -cliport 1201 -swbd ${SWBD##SWBD} -handledbcorruption $needdbcorruptiontobehandled -dbdumponfwdl $FWDL_CCMDB_DUMP_FILE -fwdlcase $firmwaredownloadcase -isabruptreboot $isabruptreboot -detectschemachange $isschemachangetobedetected -haid $haId -prevfwversion $prevFwVersion -currfwversion $currFwVersion -mgmtinterfacereceiverlist $mgmtinterfacereceiverlist -waveclientreceiverlist $waveclientreceiverlist -interlocationreceiverlist $interlocationreceiverlist -httpinterfacereceiverlist $httpinterfacereceiverlist" >> ${FWDL_DB_COPY_LOG}

    (cd /etc/fabos/Ccmd && rm -rf WaveDatabase/postmaster.opts WaveDatabase/postmaster.pid && /fabos/libexec/Ccmd.Linux.powerpc -confdport 4565 -enabledb true -dbport 7013 -mgmtport 7110 -port 5016 -clientport 7710 -eth vlan0.4093 -ipot true -daemon true -usefs false -syslog false -chdir /etc/fabos/Ccmd -vcsconfpath /etc/fabos/Ccmd -distributionmode CCM_ONLY -httpport 2401 -haport 4516 -hapeerport 4516 -cliport 1201 -swbd ${SWBD##SWBD} -handledbcorruption $needdbcorruptiontobehandled -dbdumponfwdl $FWDL_CCMDB_DUMP_FILE -fwdlcase $firmwaredownloadcase -isabruptreboot $isabruptreboot -detectschemachange $isschemachangetobedetected -haid $haId -prevfwversion $prevFwVersion -currfwversion $currFwVersion -mgmtinterfacereceiverlist $mgmtinterfacereceiverlist -waveclientreceiverlist $waveclientreceiverlist -interlocationreceiverlist $interlocationreceiverlist -httpinterfacereceiverlist $httpinterfacereceiverlist;)

    ulimit -Ss 1024;

esac


