#!/bin/bash
. /etc/init.d/functions

dcm_check_wave_database_integrity() {

    if [ -f ${FWDL_DB_COPY_LOG} ]; then
        log_to_pg_file "file check passed."
    else
        touch ${FWDL_DB_COPY_LOG} 2>/dev/null
    fi

    log_to_pg_file "DCM Starting to check WaveDatabase Integrity...."

    if [ ${iscfgcleanup} -eq 1 -o ${isautorecovery} -eq 1 ]; then
        log_to_pg_file "DCM WaveDatabase Integrity Not required as cfgcleanup/autorecovery is done in this boot...."
        log_to_pg_file dcm_check_wave_database_integrity...end 
        return 0;
    fi

    # Clean up existing cfg and log files. 

    rm -f /etc/fabos/Dcmd/WaveDatabase/postmaster.pid 2>/dev/null

    local dcm_rc=1
    dcmd_wavecurrent_exists=0
    dcmd_wavestart_exists=0

    # Only Dcmd needs to be launched
    log_to_pg_file "Dcmd needs to be launched."

    if [ ! -d /etc/fabos/Dcmd/WaveDatabase ]; then
        return 1;
    fi
    
    start_postgres_server "/etc/fabos/Dcmd/WaveDatabase" 9015 "DCM" 

    if [ $? -ne 0 ]; then
        log_to_pg_file "failed to connect to Dcmd database."

        echo "Dcmd Database is corrupted. Hence, clearing the database."
        log_to_pg_file "Dcmd Database is corrupted. Hence, clearing the database."
        rm -rf /etc/fabos/Dcmd/WaveDatabase
        rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
 
        return 1;
    fi

    /usr/local/postgresql/${POSTGRES_VERSION}/bin/psql WaveDatabase -p 9015 -c "\dn" > /tmp/dcmd_schema_info 2>&1
    dcmd_schema_output=`cat /tmp/dcmd_schema_info`
    dcmd_wavecurrent_exists=`echo ${dcmd_schema_output} | grep -c -i -e "wavecurrent"`
    dcmd_wavestart_exists=`echo ${dcmd_schema_output} | grep -c -i -e "wavestart"`
    rm -f /tmp/dcmd_schema_info

    if [ ${dcmd_wavecurrent_exists} -eq 1 -a ${dcmd_wavestart_exists} -eq 1 ]; then
        local MAX_RETRIES=60
        local SLEEP_TIME=8
        let TIMEOUT_MINUTES=${MAX_RETRIES}*${SLEEP_TIME}/60

        log_to_pg_file "postmaster running for Dcmd..Starting database dump, restore for Dcmd." 

        monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_dump" 9015 "-f /tmp/dcmd_db_dump -Ft WaveDatabase" ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
        dcm_rc=$?
        
        log_to_pg_file "dump for dcmd database ended. dcm_rc=$dcm_rc."
        
        if [ ${dcm_rc} -eq 0 ]; then
            log_to_pg_file "dcmd dump succeeded."

            clean_prepared_trasaction WaveDatabase 9015
            log_to_pg_file "dcmd clean_prepared_trasaction done."

            monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/psql" 9015 '-c "drop schema wavecurrent cascade;drop schema wavestart cascade;" WaveDatabase' ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
            dcm_rc=$?

            log_to_pg_file "dropped schemas before restore. dcm_rc=$dcm_rc."

            if [ ${dcm_rc} -eq 0 ]; then
                monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore" 9015 "-d WaveDatabase /tmp/dcmd_db_dump" ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
                dcm_rc=$?

                log_to_pg_file "restore done from the dcmd dump file taken during db corruption detection. dcm_rc=$dcm_rc."

                if [ ${dcm_rc} -eq 0 ]; then
                    monitor_postgres_client_process_with_timeout "/usr/local/postgresql/${POSTGRES_VERSION}/bin/psql" 9015 '-c "vacuum;" WaveDatabase' ${FWDL_DB_COPY_LOG} ${MAX_RETRIES} ${SLEEP_TIME}
                    dcm_rc=$?

                    log_to_pg_file "vacuum done on restored dcmd db to detect corrupted indexes. dcm_rc=$dcm_rc."
                
                    if [ ${dcm_rc} -eq 0 ]; then
                        log_to_pg_file "dcmd vacuum succeeded."
                    else
                        log_to_pg_file "dcmd vacuum failed."

                        if [ ${dcm_rc} -eq 254 ]; then
                            log_to_raslog DCM-3010 Dcmd ${TIMEOUT_MINUTES}
                        fi
                    fi
                else
                    log_to_pg_file "dcmd restore failed."

                    if [ ${dcm_rc} -eq 254 ]; then
                        log_to_raslog DCM-3010 Dcmd ${TIMEOUT_MINUTES}
                    fi
                fi
            else
                log_to_pg_file "dcmd empty database for restore preparation failed. Hence not attempting restore."

                if [ ${dcm_rc} -eq 254 ]; then
                    log_to_raslog DCM-3010 Dcmd ${TIMEOUT_MINUTES}
                fi
            fi
        else
            log_to_pg_file "dcmd dump failed. Hence not attempting restore."

            if [ ${dcm_rc} -eq 254 ]; then
                log_to_raslog DCM-3010 Dcmd ${TIMEOUT_MINUTES}
            fi
        fi

        rm -f /tmp/dcmd_db_dump
    else
        log_to_pg_file "WaveCurrent/WaveStart of Dcmd DB doesn't exist."  
        dcm_rc=0
    fi

    log_to_pg_file "stopping Dcmd postgres servers." 
    stop_postgres_server "/etc/fabos/Dcmd/WaveDatabase"

    # Cleanup Dcmd database and cfg file when database is in bad state
    if [ ${dcm_rc} -ne 0 ]; then
        echo "Dcmd Database is corrupted. Hence, clearing the database."
        log_to_pg_file "Dcmd Database is corrupted. Hence, clearing the database." 
        log_to_raslog DCM-3053 Dcmd

        rm -rf /etc/fabos/Dcmd/WaveDatabase
        rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
    else
        log_to_pg_file "Dcmd database is good." 
    fi
    # Cleanup Dcmd database and cfg file when the required schemar is missing
    if [ ${dcmd_wavecurrent_exists} -ne 1 -o ${dcmd_wavestart_exists} -ne 1 ] ; then
        echo "In Dcmd WaveDatabase, wavecurrent(${dcmd_wavecurrent_exists})/wavestart(${dcmd_wavestart_exists}) schema doesn't exist."
        echo "Treating this as Database corruption. Hence clearing the database."
        rm -rf /etc/fabos/Dcmd/WaveDatabase
        rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
    else
        log_to_pg_file "Dcmd WaveDatabase contains both wavecurrent and wavestart schemas." 
    fi

    log_to_pg_file "dcm_check_wave_database_integrity...end." 
}

dcm_copy_wavedb_from_secondary() {

    log_to_pg_file "DCM Starting to copy waveDb and confd cdb from Secondary...."

    # Clean up existing cfg and log files. 

    rm -f /mnt/etc/fabos/Dcmd/WaveDatabase/postmaster.pid ${FWDL_DCMDB_DUMP_FILE} /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg 

    # removing the cfg file as it is possible the mnt partition may not have cfg file. If that is the case, copy will fail and current partition will old incorrect data in cfg file.
    rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
    cp -f /mnt/etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg

    # removing config backup file as it is possible the mnt partition may not have backup file. If that is the case, copy will fail and current partition will old incorrect backup file.
    rm -rf /etc/fabos/Dcmd/VcsConfigBackup.*
    cp -f /mnt/etc/fabos/Dcmd/VcsConfigBackup.* /etc/fabos/Dcmd/ 2>>${FWDL_DB_COPY_LOG}

    status=1

    # copy DCMD database
    if [ -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg ]
    then
        log_stage_start "DCMd DB copy from secondary to primary"

        log_stage_start "DCMd DB server launch"
        start_postgres_server "/mnt/etc/fabos/Dcmd/WaveDatabase" 9014 "/etc/fabos/Dcmd/WaveDatabase" 9015 "DCM" 1

        if [ $? -ne 0 ]; then
            log_to_pg_file "failed to start postgres server for Dcmd" 
            # if db copy failed, we should remove cfg file
            rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
            return
        fi
        log_stage_end "DCMd DB server launch"

        log_to_pg_file postmaster running..Starting Dcmd database copy 
        log_stage_start "DCMd DB dump"
        #echo " Copying Dcmd database"
        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_dump -p 9014 -f ${FWDL_DCMDB_DUMP_FILE} -Ft WaveDatabase 2>>${FWDL_DB_COPY_LOG}
        log_stage_end "DCMd DB dump"

        log_stage_start "DCMd DB restore"
        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore -d WaveDatabase -p 9015 ${FWDL_DCMDB_DUMP_FILE} >>${FWDL_DB_COPY_LOG} 2>&1
        rc1=$?
        log_to_pg_file copy done. rc $rc1 
        if [ $rc1 -ne 0 ]
        then
            log_to_pg_file Dcmd DB restore failed whil restoring from mnt partition . retStatus = $rc1 
            log_to_pg_file Hence to recover from this DB corruption, going to First time boot.
            rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
        fi
        log_stage_end "DCMd DB restore"
        #echo " done"

        stop_postgres_server "/mnt/etc/fabos/Dcmd/WaveDatabase" "/etc/fabos/Dcmd/WaveDatabase"
        log_stage_end "DCMd DB copy from secondary to primary"
    fi

    log_to_pg_file dcm_copy_wavedb_from_secondary...end 
}

#
# In case of db conversion not handled because of reboot in middle, 
#   1. restore the database to its last good state using the pg_dump collected while FWDL.
#   2. pass detectSchemaChange flag to true to have Dcmd/Ccmd carry schema comparison and take appropriate action.
#   3. file $FWDL_DCMDB_DUMP_FILE will be renamed to $FWDL_DCMDB_DUMP_FILE".done" in Dcmd/Ccmd sources after completion of schema mismatch detection logic completion. 
#       Hence, help here to make sure that the node is rebooted before schema conversion completion.
#
dcm_handle_db_restore_if_required() {

    #Dcmd handling
    if [ -f $FWDL_DCMDB_DUMP_FILE ]; 
    then

        # Restore DCM DB as db converison was not complete.
        log_to_pg_file "############## Restoring the DCM database as db conversion was not complete.######################" 

        rm -f /etc/fabos/Dcmd/WaveDatabase/postmaster.pid 
        
        start_postgres_server "/etc/fabos/Dcmd/WaveDatabase" 9015 "DCM" 

        if [ $? -ne 0 ]; then
            log_to_pg_file "failed to connect to Dcmd database" 
            return
        fi

        log_to_pg_file "postmaster running..Starting database copy" 
        
        clean_prepared_trasaction WaveDatabase 9015
        log_to_pg_file dcmd clean_prepared_trasaction done

        /usr/local/postgresql/${POSTGRES_VERSION}/bin/psql WaveDatabase -p 9015 -c "drop schema wavecurrent cascade;drop schema wavestart cascade;" >>${FWDL_DB_COPY_LOG} 2>&1
        rc1=$?
        log_to_pg_file dropped schemas before restore rc=$rc1 

        /usr/local/postgresql/${POSTGRES_VERSION}/bin/pg_restore -d WaveDatabase -p 9015 ${FWDL_DCMDB_DUMP_FILE} >>${FWDL_DB_COPY_LOG} 2>&1
        rc1=$?
        log_to_pg_file copy done. rc $rc1 
        if [ $rc1 -ne 0 ]
        then
            log_to_pg_file Dcmd DB restore failed whil restoring $FWDL_DCMDB_DUMP_FILE. retStatus = $rc1 
            log_to_pg_file Hence to recover from this DB corruption, going to First time boot.
            rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
        fi
        #echo " done"

        stop_postgres_server "/etc/fabos/Dcmd/WaveDatabase"

        isschemachangetobedetected="true"
        # Reset abrupt reboot to false as we restored the old DB and hence no need of DB Sanity check
        isabruptreboot="false"
    fi

}

dcm_cfg_cleanup() {
    rm -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
    rm -rf /etc/fabos/Dcmd/VcsConfigBackup.*

    if [ -d /var/tmp/vCenter ]; then
       rm -f /var/tmp/vCenter/*
    fi
    if [ -d /mnt/var/tmp/vCenter ]; then
       rm -f /mnt/var/tmp/vCenter/*
    fi

    rm -rf /etc/fabos/Nspd/WaveDatabase
    rm -f /etc/fabos/Nspd/Nspd.Linux.powerpc.cfg

    log_to_pg_file "Dcm : Removing Dcmd.*.cfg file as this reboot was after cfgcleanup."
}

dcm_handle_fwdl() {
    swbd_num=${SWBD##SWBD}
    log_to_pg_file dcm_handle_fwdl : swbd_num:${swbd_num}
    rb_reason=`cat /mnt/var/rb_reason`
    log_to_pg_file "dcm_handle_fwdl : ******Reboot reason : ${rb_reason}******"

    PG_VERSION=`ls /usr/local/postgresql | cut -d '/' -f1`

    PGMNT_VERSION=`ls /mnt/usr/local/postgresql | cut -d '/' -f1`

    # In fwdl case, vcs.conf needs to be copied from secondary partition before we determine the number of daemons
	
    cp -f /mnt/etc/fabos/Dcmd/vcs.conf /etc/fabos/Dcmd/vcs.conf

    rm -rf /etc/fabos/Dcmd/PrismDatabase.previous.pgd
    rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.trc*
    cp -f /mnt/etc/fabos/Dcmd/Dcmd.Linux.powerpc.trc* /etc/fabos/Dcmd/
    rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.pg_ctl.log*
    cp -f /mnt/etc/fabos/Dcmd/Dcmd.Linux.powerpc.pg_ctl.log* /etc/fabos/Dcmd/

    isschemachangetobedetected="true"
    isissufwdl=0   
    is_issu_fwdl_reboot ${rb_reason}
    if [ $? -eq 1 ]; then
        isissufwdl=1
    fi

    #copy postgres related files only when there is no postgres's version change

    if [ $PG_VERSION == $PGMNT_VERSION ]
    then
        if [ -f /mnt/etc/fabos/Dcmd/PrismDatabase.previous.pgd ]
        then
            cp /mnt/etc/fabos/Dcmd/PrismDatabase.previous.pgd /etc/fabos/Dcmd/PrismDatabase.previous.pgd
        fi
    
        if [ -f /mnt/etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd ]; then
            dcm_cfg_cleanup
            iscfgcleanup=1

            if [[( ! -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg && ! -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg )]]; then
                rm -f /mnt/etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd
            fi
        elif [ ${isissufwdl} -eq 1 ];then
            dcm_cfg_cleanup
            iscfgcleanup=1

            log_to_pg_file "Cfgcleanup done on standbyGOS for ISSU FWDL"
        else
            dcm_copy_wavedb_from_secondary

            if [ -f /mnt/etc/fabos/Dcmd/SchemaConversionDwnGrd.sh ]; then
                cp /mnt/etc/fabos/Dcmd/SchemaConversionDwnGrd.sh /etc/fabos/Dcmd/SchemaConversionDwnGrd.sh
            
                /etc/fabos/Dcmd/SchemaConversionDwnGrd.sh
            fi
        fi
    fi   

    rm -f /etc/fabos/NosSmd/yangNew/.extraction_completed
    rm -f /etc/fabos/NosSmd/yangNew/*.xml
    
    current_dcm_mode=$(get_dcm_mode)    

    if [ $current_dcm_mode -eq 0 ] || [ $current_dcm_mode -eq 2 ]; then 
    
        # Check what the startup file in previous partition is pointing to
        startfileName=`/bin/ls -l /mnt/etc/fabos/Dcmd/startupFile | awk '{print $11}'`

        echo "startupFile Name =>> ${startfileName}"

        # In case of non-default startupFile, copy to current partition and update link
        if [ $startfileName != '/etc/fabos/Dcmd/defaultconfig.vcs' -a $startfileName != '/etc/fabos/Dcmd/defaultconfig.novcs' ]
        then
            cp -f /mnt${startfileName} $startfileName 
        else
            # clear stale startup-config
            rm -f /var/config/vcs/scripts/startup-config

            # In case of FC/SA mode, after copy default to start is done and firmware download is done then Dcmd should boot in First Time boot and hence remove the cfg file
            # This is done as Dcmd do not have capability to call both upgrade and install methods of all OMs in Dcmd bootup.
            log_to_pg_file "Upgrade done with default config. Since no config exist, Dcmd will boot up with First time boot and hence removing cfg file...."
            rm -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
        fi

        (cd /etc/fabos/Dcmd; /bin/ln -sf $startfileName ./startupFile)
    fi

    firmwaredownloadcase=`cat /etc/fabos/Dcmd/vcs.conf.fwdl`
    rm -f /etc/fabos/Dcmd/vcs.conf.fwdl

    # create a backup file of startupFile to be used for parsing in earlyConfigReplay step if required
    touch /etc/fabos/Dcmd/startupFile.bk

    # to keep db conversion disabled after fwdl: touch file /etc/fabos/Dcmd/disableschemaconversion
    # AND in Ccmd everytime on boot-up (as Ccmd has detectSchemaChange flag enabled on every boot.)
    # both the lines ('touch /etc/fabos/Dcmd/disableschemaconversion' and 'touch /etc/fabos/Ccmd/disableschemaconversion') will be removed from this file when db conversion is to be enabled. 
    #touch /etc/fabos/Dcmd/disableschemaconversion

    # copy all snapshot files into current partition
    # first create the snapshot directory, otherwise copy command fails during copy from secondary partition to primary partition.
    # This can occur after netinstall or upgrading from hydra build to leo build. 
    mkdir -p /etc/fabos/Dcmd/ConfigSnapshot/
    rm -f /etc/fabos/Dcmd/ConfigSnapshot/*.cs
    for i in `/bin/ls -l /mnt/etc/fabos/Dcmd/ConfigSnapshot/*.cs 2>/dev/null | awk '{print $9}' | awk -F / '{print $7}'`
    do
      cp -f /mnt/etc/fabos/Dcmd/ConfigSnapshot/$i /etc/fabos/Dcmd/ConfigSnapshot/$i
    done


    if [ ${swbd_num} -lt 1004 -o ${swbd_num} -gt 1007 ]; then
        is_abrupt_reboot ${rb_reason}
        if [ $? -eq 1 ]; then
            isabruptreboot="true"
        fi
    fi
}

dcm_handle_reboot() {

    swbd_num=${SWBD##SWBD}
    log_to_pg_file dcm_handle_reboot : swbd_num:${swbd_num}
    rb_reason=`cat /var/rb_reason`
    log_to_pg_file "dcm_handle_reboot : ******Reboot reason : ${rb_reason}******"

    if [ "pAutoRecoveryForDBCorruption" == p"${rb_reason}" ]; then
        if [ -f /etc/fabos/Dcmd/.WaveDatabaseFoundCorrupted ]; then 
                log_to_pg_file "Dcm : Removing Dcmd.*.cfg file as this reboot was because of auto recovery for database corruption."
                rm -rf /etc/fabos/Dcmd/*cfg /etc/fabos/Dcmd/*cfg.bk
                isautorecovery=1
        fi
    fi

    if [ -f /etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd ]; then
        dcm_cfg_cleanup
        iscfgcleanup=1

        if [[( ! -f /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg && ! -f /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg )]]; then
            rm -f /etc/fabos/Dcmd/.__dcmccm__cfgonlycleanupreqd
        fi
    fi

    if [ ${swbd_num} -lt 1004 -o ${swbd_num} -gt 1007 ]; then
        ishafailover=0
        is_ha_failover_reboot ${rb_reason}
        if [ $? -eq 1 ]; then
            ishafailover=1
            log_to_pg_file "Dcm : ishafailover = "$ishafailover
        fi
        
        isTorSwitch=0
        is_tor_switch ${swbd_num}
        if [ $? -eq 1 ]; then
            isTorSwitch=1
            log_to_pg_file "Dcm : isTorSwitch = "$isTorSwitch
        fi

        if [ ${isTorSwitch} -eq 1 -a ${ishafailover} -eq 1 ]; then
            log_to_pg_file "Dcm : This is a case of haFailover on TOR platform. Hence, clearing the cfg and db."
            dcm_cfg_cleanup
            iscfgcleanup=1  
        else 
            is_abrupt_reboot ${rb_reason}
            if [ $? -eq 1 ]; then
                isabruptreboot="true"
                if [ ${swbd_num} -ne 138 ]; then
                    dcm_check_wave_database_integrity
                else
                    /fabos/libexec/mmi_early_sr6_update
                    if [ $? -eq 1 ]; then
                        dcm_check_wave_database_integrity
                    else
                        rm -rf /etc/fabos/Dcmd/WaveDatabase
                        rm -rf /etc/fabos/Dcmd/Dcmd.Linux.powerpc.cfg
                    fi
            fi
        fi
        fi

        dcm_handle_db_restore_if_required
    fi
}


SWBD=`sin | swbd 2> ${NULL}`
CPID=`sin | cpid 2> ${NULL}`

#
# Emulator Support
#
MY_EMUL_FILE=/users/emulator
EMUSWBD=""
if [ -a $MY_EMUL_FILE ]; then
	EMUSWBD=`cat $MY_EMUL_FILE`
	echo $EMUSWBD ${EMUSWBD##SWBD}
	case ${EMUSWBD##SWBD} in
		'1' )
			echo "Emulation $EMUSWBD/153 Platform"
			SWBD="SWBD153"
			;;
		'153' | '154' )
			echo "Emulation $EMUSWBD Platform"
			SWBD=$EMUSWBD
			;;
		*)
			echo "  "
			;;
	esac
fi

echo "Starting Dcmd ... `/bin/date`"

isschemachangetobedetected="false"
needdbcorruptiontobehandled="true"
firmwaredownloadcase=0                                       #0 - no firmware download case, 1 - firmware upgrade case, 2 firmware downgrade case
isabruptreboot="false"
isautorecovery=0
iscfgcleanup=0

# Check if VCS needs to be enabled.
if [ -f /etc/fabos/vcs/vcs.conf ]; then
    SYSDRV_CONFIG=1 #$(($SYSDRV_CONFIG | $SYS_CFG_VCS_ENABLED))
fi

# to keep db conversion disabled after fwdl: touch file /etc/fabos/Dcmd/disableschemaconversion
# AND in Ccmd everytime on boot-up (as Ccmd has detectSchemaChange flag enabled on every boot.)
# both the lines ('touch /etc/fabos/Dcmd/disableschemaconversion' and 'touch /etc/fabos/Ccmd/disableschemaconversion') will be removed from this file when db conversion is to be enabled. 
# touch /etc/fabos/Ccmd/disableschemaconversion

# Persist the VCS mode from previous partition in case of firmware upgrade
# Note :Existence of the file /etc/fabos/Dcmd/vcs.conf.fwdl denotes the firmware download case 
#       And the content of the file gives the fwdl case (i.e. 0:same/nightly firmware download, 1:fwdl upgrade, -1:fw downgrade).
if [ -f /etc/fabos/Dcmd/vcs.conf.fwdl ]
then
    dcm_handle_fwdl
else
    dcm_handle_reboot
fi   #End of vcs.conf.fwdl check


# Number of daemons needs to be reassigned at this point because the value of vcs.conf might be changed in firmwaredownload case        
dcm_mode=$(get_dcm_mode)

if [ $dcm_mode -ne 0 ]
then
    log_to_pg_file "Ccm: Remove Ccmd WaveDatabase and cfg file since it won't be used."
    rm -rf /etc/fabos/Ccmd/WaveDatabase 
    rm -rf /etc/fabos/Ccmd/Ccmd.Linux.powerpc.cfg
fi



$ECHO -n "Starting Dcmd ... "
$ECHO `/bin/date`

# Delete Config Snapshot files if the switch is in non-MC mode
# Reasons and scenarios handled:
# * mode transitions from MC to SA/FC need to delete the snapshot files as snapshot feature is not supported in SA/FC modes
# * for mode transition from SA/FC to MC, nothing will be deleted as snapshot files won't be present anyway
# * in MC, during cluster formation, snapshot files of secondary nodes are deleted in Dcmd code
if [ $dcm_mode -ne 1 ]
then
   log_to_pg_file "Removing snapshot files as dcm mode is "$dcm_mode 
   rm -f /etc/fabos/Dcmd/ConfigSnapshot/*.cs    
fi

# Delete all event-handler python scripts on boot up.
# Reasons and scenarios handled:
# * Copy default to start for MC/FC modes followed by reload will not clean any event-handler python script actions.
# * Ensure we clean up these action scripts on every reboot since postboot will activate any configured event-handlers 
# * and recreate the action scripts.  Deleting python action scripts on a copy default to start operation may be difficult
# * especially if action is triggered or executed during the copy d to s operation so handling cleanup on switch bootup. 
log_to_pg_file "Removing event-handler python action scripts."
rm -f /etc/fabos/Dcmd/python/scripts/*.py
rm -f /etc/fabos/Dcmd/python/scripts/*.pyc

# Get the HaId using sin
cpId=`/sbin/sin | grep "Control Processor" | cut -d':' -f2`
haId=`expr ${cpId} + 1`

# lo            = loopback interface
# eth0          = management interface
# eth1          = interface communication b/w Standby GOS and Active GOS
# vlan0.4093    = remote communications
# eth2          = backplane interface

mgmtinterfacereceiverlist="lo:eth0:"
waveclientreceiverlist="lo:eth0:"
interlocationreceiverlist="vlan0.4093:"
httpinterfacereceiverlist="lo:"

case ${SWBD##SWBD} in
'1000' | '1001' | '1002' | '1003')
    # include backplane interface for a chassis system
    backplaneinterface="eth2:"
    mgmtinterfacereceiverlist=${mgmtinterfacereceiverlist}${backplaneinterface}${interlocationreceiverlist}
    waveclientreceiverlist=${waveclientreceiverlist}${backplaneinterface}${interlocationreceiverlist}
    ;;
'131' | '137' | '138' | '151' | '153' | '154' | '155' | '156' | '164')
    # include GOS communication interface for a castor/castor-t, embedded s/w
    standbyGOSConnectToActiveGOS="eth1:"
    mgmtinterfacereceiverlist=${mgmtinterfacereceiverlist}${standbyGOSConnectToActiveGOS}${interlocationreceiverlist}
    waveclientreceiverlist=${waveclientreceiverlist}${standbyGOSConnectToActiveGOS}${interlocationreceiverlist}
esac

case ${SWBD##SWBD} in
'1004' | '1005' | '1006' | '1007')
    ;;
*)
    # Limit Stack size to 1 MB.
    ulimit -Ss 256

    # Untar YinFiles if not already extracted
    if [ ! -f '/etc/fabos/NosSmd/yangNew/.extraction_completed' ]
    then
        tar -xf /etc/fabos/NosSmd/yangNew/YinFiles.tar -C /etc/fabos/NosSmd/yangNew/ > /dev/null 2>&1
        touch /etc/fabos/NosSmd/yangNew/.extraction_completed
    fi

    log_to_pg_file dcmd : schemachangetobedetected=${isschemachangetobedetected}
    log_to_pg_file dcmd : isabruptreboot=${isabruptreboot}

    # swbd is mandatory while starting Dcmd,Ccmd and the value should not be zero    
    if [ $dcm_mode -ne 0 ]
    then
       (cd /etc/fabos/Dcmd && rm -rf WaveDatabase/postmaster.opts WaveDatabase/postmaster.pid && /fabos/libexec/Dcmd.Linux.powerpc -confdport 4565 -enabledb true -eth vlan0.4093 -ipot true -detectschemachange $isschemachangetobedetected -daemon true -usefs false -syslog false -chdir /etc/fabos/Dcmd -vcsconfpath /etc/fabos/Dcmd -distributionmode DCM_CCM -httpport 2301 -haport 3516 -hapeerport 3516 -cliport 1101 -swbd ${SWBD##SWBD} -handledbcorruption $needdbcorruptiontobehandled -dbdumponfwdl $FWDL_DCMDB_DUMP_FILE -fwdlcase $firmwaredownloadcase -yinpath /etc/fabos/NosSmd/yangNew -isabruptreboot $isabruptreboot -haid $haId -prevfwversion $prevFwVersion -currfwversion $currFwVersion -mgmtinterfacereceiverlist $mgmtinterfacereceiverlist -waveclientreceiverlist $waveclientreceiverlist -interlocationreceiverlist $interlocationreceiverlist -httpinterfacereceiverlist $httpinterfacereceiverlist;)
    #   (cd /etc/fabos/NosSmd && /fabos/libexec/NosSmd.Linux.powerpc -dbport 19013 -mgmtport 19110 -port 13016 -clientport 19710 -httpport 12401 -haport 13516 -confdport 4565 -cliport 11101 -daemon true -swbd ${SWBD##SWBD} -eth vlan0.4093 -ipot true -usefs false -syslog false -chdir /etc/fabos/NosSmd -yinpath /etc/fabos/NosSmd/yangNew -server DCMD:127.0.0.1:9110;)
    fi
    if [ $dcm_mode -eq 0 ]
    then
       (cd /etc/fabos/Dcmd && rm -rf WaveDatabase/postmaster.opts WaveDatabase/postmaster.pid && /fabos/libexec/Dcmd.Linux.powerpc -confdport 4565 -enabledb true -eth vlan0.4093 -ipot true -detectschemachange $isschemachangetobedetected -daemon true -usefs false -syslog false -chdir /etc/fabos/Dcmd -yinpath /etc/fabos/NosSmd/yangNew -vcsconfpath /etc/fabos/Dcmd -distributionmode DCM_ONLY -httpport 2301 -haport 3516 -hapeerport 3516 -cliport 1101 -swbd ${SWBD##SWBD} -handledbcorruption $needdbcorruptiontobehandled -dbdumponfwdl $FWDL_DCMDB_DUMP_FILE -fwdlcase $firmwaredownloadcase -isabruptreboot $isabruptreboot -haid $haId -server "CCMD:127.0.0.1:7110" -prevfwversion $prevFwVersion -currfwversion $currFwVersion -mgmtinterfacereceiverlist $mgmtinterfacereceiverlist -waveclientreceiverlist $waveclientreceiverlist -interlocationreceiverlist $interlocationreceiverlist -httpinterfacereceiverlist $httpinterfacereceiverlist;)
     #  (cd /etc/fabos/NosSmd && /fabos/libexec/NosSmd.Linux.powerpc -dbport 19013 -mgmtport 19110 -port 13016 -clientport 19710 -httpport 12401 -haport 13516 -confdport 4565 -cliport 11101 -swbd ${SWBD##SWBD} -daemon true -usefs false -syslog false -chdir /etc/fabos/NosSmd -yinpath /etc/fabos/NosSmd/yangNew -server "DCMD:127.0.0.1:9110;CCMD:127.0.0.1:7110";)
    fi

    /fabos/bin/monitorandrestart_smd.sh &

    ulimit -Ss 1024;

esac


