#!/bin/bash
# Function to reduce the number of core files in a directory to
# a maximum of $KEEP. Delete from the oldest to the newest

# Defaults, can be overridden using command parameters

# Available disk spcae is around 395M when disk utilization is 80%, so keeping desired space 390M
DESIRED_SPACE=390000
DESIRED_PERCENT=80
DO_GZIP=0
MAX_FILES=5
GZIP=/bin/gzip
RM=/bin/rm
TRACEPD_DIR=/var/trace
COREFILES_DIR=/core_files

shopt -s extglob nullglob

# A newline, used to help read difficult filenames
nl='
'

# Remove files from directory $1 (get back by going to $2) that are either
# core or core.[0-9][0-9]*. However keep at least $KEEP of them, which are
# the newest.
# Make use of the GNU ls program, which can output filenames
# like "fred" or "bill\"", including quotes

trimdir(){
	# echo "trimdir=$1"
	cd "$1"
	olddir="$2"
	# Do a quick check before we bother calling ls
	set -- core?(.+([0-9]))?(.gz)
	# echo "file num=$# keep=$KEEP"
	if [[ $# -gt $KEEP ]] ; then
		# Read in the core file names, dealing with weird characters
		# echo "read core file"
		OIFS="$IFS"; IFS="$nl"
		set -- $(ls --quoting-style=c -t1d "$@" 2>/dev/null)
		IFS="$OIFS"
		if [[ $# -gt $KEEP ]] ; then
			shift $KEEP
			# echo "ls core file"
			for filename ; do
				# Strip off the " that the ls put on.
				j=${filename#\"}; j=${j%\"}; j=${j//\\\"/\"}
				# Append full pathname to the togo array
				togo[$C]="$(printf %s/%b "$PWD" "$j" )"
				# echo "rm file="$(printf %s/%b "$PWD" "$j" )""
				$(/fabos/link_sbin/errlogtest -i FW-1409 -a "$percent" "%" "$(printf %s/%b "$PWD" "$j" )")
				let C+=1
			done
		fi
	fi
	cd "$olddir"
}

compress_in_dir(){
	# echo "compress in dir=$1"
	cd "$1"
	olddir="$2"
	set -- core?(.+([0-9]))
	[ $# -gt 0 ] && $GZIP -f "$@"
	cd "$olddir"
}

# loop over directories except panic and trim each one.

tidy(){
	let C=0
	unset togo
	for i in !(panic)/.
	do
        if [ $i != "sassvrd/." ] &&
           [ $i != "dpc/." ] &&
           [ $i != "sattoold/." ]
        then
			trimdir "$i" ..
		fi
	done
	if [[ $C -gt 0 ]] ; then
		$RM -- "${togo[@]}"
	fi
}

compress_all_core_files(){
	for i in !(panic)/.
	do
        if [ $i != "sassvrd/." ] &&
           [ $i != "dpc/." ] &&
           [ $i != "sattoold/." ]
        then
			compress_in_dir "$i" ..
		fi
	done
}


# Return 0 when then is enough space, 1 otherwise
space(){
	set -- $(df .)
	# Skip header ("filesystem 1k-blocks used available use% mounted on")
	shift 7
	# $1=where, $2=size, $3=used $4=Avail $5=Use% $6=mnt_point
	percent=${5%\%}
	# Can either use DESIRED_SPACE as a number of blocks
	# echo "SPACE Exp=$DESIRED_SPACE Curr=$4"
	if [[ $4 -le $DESIRED_SPACE ]] ; then return 1 ; else return 0 ; fi
}

# Scan tracepd dump files and keep not more than 5 files.
checkCount() {
        file_name=$*
        set -- $(df .)
         # Skip header , same as in space()
        shift 7
        percentage=${5%\%}   
        set -- $file_name
	while [ $# -gt $MAX_FILES ] ; do
		$(/fabos/link_sbin/errlogtest -i FW-1410 -a "$1")
		/bin/rm "$1"
		shift
	done
}	
# Loop, with smaller and smaller values of KEEP until we have enough space
# Returns 0 is there is enough space, 1 otherwise
tidy_till_space(){
	# Loop through /var/trace and /core_files to remove excess tracepd, 
	# core and other dump files
	checkCount ${TRACEPD_DIR}/tracepd*od
	for dir in $(find $COREFILES_DIR -type d)
	do
		if [ "$dir" == "$COREFILES_DIR" ] ; then 
			continue
		fi
		core=`find $dir -name "core*"`
		misc=`find $dir -name "misc*"`
		if [[ -n "$core" ]] ; then
			core_sorted=`/bin/ls -tr $core`
			checkCount $core_sorted
		fi
		if [[ -n "$misc" ]] ; then
			misc_sorted=`/bin/ls -tr $misc`
			checkCount $misc_sorted
		fi
	done	

	for KEEP in 4 3 2 1; do
		if space ; then return  0; fi
		tidy
	done
	# Do it one more time to set return code
	space
}

usage(){
	u="Usage: $0 [-c] [-p percent_space] [-n desired_free_blocks] [-P rm_program]" 
	echo "$u" >&2
	echo "Usage: $0 -h [this help]" >&2
	exit ${1:-2}
}

# Main program.
# Decode arguements
while getopts "hcp:n:P:" option ;do
	case "$option" in
	c)  DO_GZIP=1 ;;
	p)	DESIRED_PERCENT="$OPTARG" ;;
	n)	DESIRED_SPACE="$OPTARG" ;;
	P)	RM="$OPTARG" ;;
	h)	usage 0;;
	\?)	usage ;;
	esac
done
shift $(($OPTIND - 1))

if [ $# -ne 0 ] ; then
	usage
fi

# First attempt to compress files that can be compressed
if [ $DO_GZIP -eq 1 ]; then 
	compress_all_core_files
fi

# clean up additional files 
tidy_till_space
